==> haskell-quickcheck-2.10.0.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: QuickCheck
version: 2.10.0.1
id: QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
key: QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
license: BSD3
copyright: 2000-2017 Koen Claessen, 2006-2008 Björn Bringert, 2009-2017 Nick Smallbone
maintainer: Nick Smallbone <nick@smallbone.se>; see also QuickCheck mailing list (https://groups.google.com/forum/#!forum/haskell-quickcheck)
homepage: https://github.com/nick8325/quickcheck
synopsis: Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    .
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    .
    Specifications are expressed in Haskell, using combinators defined in the
    QuickCheck library. QuickCheck provides combinators to define properties,
    observe the distribution of test data, and define test data generators.
    .
    The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>
    explains how to write generators and properties;
    it is out-of-date in some details but still full of useful advice.
    .
    A user of QuickCheck has written an unofficial, but detailed, tutorial which
    you can find at
    <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>.
category: Testing
author: Koen Claessen <koen@chalmers.se>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Function
    Test.QuickCheck.Gen Test.QuickCheck.Gen.Unsafe
    Test.QuickCheck.Modifiers Test.QuickCheck.Monadic
    Test.QuickCheck.Poly Test.QuickCheck.Property
    Test.QuickCheck.Random Test.QuickCheck.State Test.QuickCheck.Test
    Test.QuickCheck.Text
abi: 2c4212a9c69c9d234eb81396b5fd082b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/QuickCheck-2.10.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/QuickCheck-2.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/QuickCheck-2.10.0.1
hs-libraries: HSQuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
depends:
    base-4.10.0.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK containers-0.5.10.2
    transformers-0.5.2.0 deepseq-1.4.3.0 template-haskell-2.12.0.0
    tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
haddock-interfaces: /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html: /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-2.10.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: QuickCheck
version: 2.10.1
id: QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
key: QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
license: BSD3
copyright: 2000-2017 Koen Claessen, 2006-2008 Björn Bringert, 2009-2017 Nick Smallbone
maintainer: Nick Smallbone <nick@smallbone.se>; see also QuickCheck mailing list (https://groups.google.com/forum/#!forum/haskell-quickcheck)
homepage: https://github.com/nick8325/quickcheck
synopsis: Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    .
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    .
    Specifications are expressed in Haskell, using combinators defined in the
    QuickCheck library. QuickCheck provides combinators to define properties,
    observe the distribution of test data, and define test data generators.
    .
    The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>
    explains how to write generators and properties;
    it is out-of-date in some details but still full of useful advice.
    .
    A user of QuickCheck has written an unofficial, but detailed, tutorial which
    you can find at
    <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>.
category: Testing
author: Koen Claessen <koen@chalmers.se>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Function
    Test.QuickCheck.Gen Test.QuickCheck.Gen.Unsafe
    Test.QuickCheck.Modifiers Test.QuickCheck.Monadic
    Test.QuickCheck.Poly Test.QuickCheck.Property
    Test.QuickCheck.Random Test.QuickCheck.State Test.QuickCheck.Test
    Test.QuickCheck.Text
abi: 31c7a57798b8306ee987164ad717d7a8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/QuickCheck-2.10.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/QuickCheck-2.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/QuickCheck-2.10.1
hs-libraries: HSQuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
depends:
    base-4.10.0.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK containers-0.5.10.2
    transformers-0.5.2.0 deepseq-1.4.3.0 template-haskell-2.12.0.0
    tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
haddock-interfaces: /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html: /usr/share/doc/haskell-quickcheck/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
